======================================
neutcurve
======================================
.. image:: https://travis-ci.org/jbloomlab/neutcurve.svg
    :target: https://travis-ci.org/jbloomlab/neutcurve.svg

.. image:: https://img.shields.io/pypi/v/neutcurve.svg
        :target: https://pypi.python.org/pypi/neutcurve

``neutcurve`` is a Python package written by the `Bloom lab <https://research.fhcrc.org/bloom/en.html>`_ for plotting neutralization curves.

See the `neutcurve documentation <https://jbloomlab.github.io/neutcurve/>`_ for details on how to install and use ``neutcurve``.
